

#import "igCalendarNavigation.h"

@interface igCalendarNavigation()<IGCalendarAppointmentDataSource, IGCalendarViewDelegate>
{
    NSMutableArray* _dataSources;
    IGCalendarView* _cal;
    NSArray* _appts;
    
    id<IGCalendarThemeDefinition> _theme;
    UISegmentedControl* _segmentView;
}

@end

@implementation igCalendarNavigation

-(void)viewDidLoad
{
    [super viewDidLoad];
    
    _dataSources = [[NSMutableArray alloc]init];
    
    [_dataSources addObject:self];
    
    [self loadAppts];
    
    self.view.backgroundColor = [UIColor colorWithWhite:.97 alpha:1];
    
     NSArray* options = [NSArray arrayWithObjects:NSLocalizedString(@"Year", @"Year"), NSLocalizedString(@"Month", @"Month"),  NSLocalizedString(@"Week", @"Week"), NSLocalizedString(@"Day", @"Day"), nil];
    
    _segmentView = [[UISegmentedControl alloc]initWithItems:options];
    _segmentView.segmentedControlStyle = UISegmentedControlStyleBar;
    _segmentView.selectedSegmentIndex = 0;
    [_segmentView addTarget:self action:@selector(navigate) forControlEvents:UIControlEventValueChanged];
    
    CGFloat segmentWidth = self.iPhone ? 235 : 325;
    
    _segmentView.frame = CGRectMake((self.view.frame.size.width - segmentWidth)/2, 10, segmentWidth, 30);
    _segmentView.autoresizingMask = UIViewAutoresizingFlexibleLeftMargin | UIViewAutoresizingFlexibleRightMargin;
    [self.view addSubview:_segmentView];
    _segmentView.tintColor = [UIColor colorWithRed:236.0f/255.0f green:55.0f/255.0f blue:49.0f/255.0f alpha:1];
    
    CGFloat top = _segmentView.frame.origin.y + _segmentView.frame.size.height;
    _cal = [[IGCalendarView alloc]initWithFrame: CGRectMake(0, top, self.view.frame.size.width, self.view.frame.size.height - top)];
    _cal.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
    _cal.monthViewDayClickAction = IGCalendarMonthViewDayClickActionNavigateToWeek;
    _cal.delegate = self;
    [self.view addSubview:_cal];
    
    _cal.appointmentDataSources = _dataSources;
    
        [_cal navigateToDate:[NSDate date] forType:IGCalendarViewDisplayTypeWeek];
    

}


/*SNIPPET*/

// The dayView was navigated to, update the tab bar.
-(void)calendarView:(IGCalendarView *)calView dayChanged:(NSDate *)date
{
    _segmentView.selectedSegmentIndex = 3;
}

-(void)calendarView:(IGCalendarView *)calView weekChanged:(NSDate *)date
{
    _segmentView.selectedSegmentIndex = 2;
}

// The monthView was navigated to, update the tab bar.
-(void)calendarView:(IGCalendarView *)calView monthChanged:(NSDate *)date
{
    _segmentView.selectedSegmentIndex = 1;
}

// The yearView was navigated to, update the tab bar.
-(void)calendarView:(IGCalendarView *)calView yearChanged:(NSDate *)date
{
    _segmentView.selectedSegmentIndex = 0;
}

-(void)navigate
{
    // The segements selected index changed.
    NSInteger index = [_segmentView selectedSegmentIndex];
    
    // Grab the current date from the calendar.
    NSDate* date = [_cal currentDate];
    
    if(index == 0) // Year
    {
        // Navigate to the YearView
        [_cal navigateToDate:date forType:IGCalendarViewDisplayTypeYear];
    }
    else if(index == 1) // Month
    {
        // Navigate to the MonthView
        [_cal navigateToDate:date forType:IGCalendarViewDisplayTypeMonth];
    }
    else if(index == 2) // Month
    {
        // Navigate to the MonthView
        [_cal navigateToDate:date forType:IGCalendarViewDisplayTypeWeek];
    }
    else // Day
    {
        // Navigate to the DayView
        [_cal navigateToDate:date forType:IGCalendarViewDisplayTypeDay];
    }
}
/*ENDSNIPPET*/

-(UIColor *)colorForAppointmentsInIGCalendarView:(IGCalendarView *)calView
{
    return [UIColor colorWithRed:237.0f/255 green:91.0f/255 blue:36.0f/255 alpha:1];
}

/*SNIPPET*/
-(void)calendarView:(IGCalendarView *)calView asyncAppointmentRequest:(IGCalendarAppointmentRequest *)request ofType:(IGCalendarAppointmentRequestType)requestType
{
    [[[NSOperationQueue alloc]init] addOperation:[NSBlockOperation blockOperationWithBlock:^(void)
                                                  {
                                                      NSTimeInterval min = [request.start timeIntervalSince1970];
                                                      NSTimeInterval max = [request.end timeIntervalSince1970];
                                                      
                                                      NSMutableArray* returnAppts = [[NSMutableArray alloc]init];
                                                      
                                                      for(NSDictionary* appt in _appts)
                                                      {
                                                          NSDate* startTime = appt[@"start"];
                                                          NSDate* endTime = appt[@"end"];
                                                          
                                                          NSTimeInterval current = [startTime timeIntervalSince1970];
                                                          NSTimeInterval currentEnd = [endTime timeIntervalSince1970];
                                                          
                                                          if((current >= min && current <= max)  ||  (currentEnd >= min && currentEnd <= max) || (current <= min && currentEnd >= max) )
                                                          {
                                                              IGCalendarAppointment* calAppt = [[IGCalendarAppointment alloc]init];
                                                              calAppt.startTime = startTime;
                                                              calAppt.endTime = appt[@"end"];
                                                              calAppt.location = appt[@"location"];
                                                              calAppt.title = appt[@"title"];
                                                              
                                                              [returnAppts addObject:calAppt];
                                                          }
                                                          
                                                      }
                                                      
                                                      [[NSOperationQueue mainQueue] addOperation: [NSBlockOperation blockOperationWithBlock:^(void)
                                                                                                   {
                                                                                                       NSArray* appts = [NSArray arrayWithArray:returnAppts];
                                                                                                       
                                                                                                       /***** CALL THIS METHOD TO NOTIFY THE CALENDAR ONCE YOU HAVE YOUR APPOINTMENTS*****/
                                                                                                       [request provideAppointments:appts];
                                                                                                   }]];
                                                      
                                                  }]];
}
/*ENDSNIPPET*/

-(void)loadAppts
{
    
    [[[NSOperationQueue alloc]init] addOperation:[NSBlockOperation blockOperationWithBlock:^(void)
                                                  {
                                                      
                                                      NSString* filepath = [[NSBundle mainBundle] pathForResource:@"appts" ofType:@"csv"];
                                                      
                                                      NSError *err;
                                                      NSString *dataRaw = [NSString stringWithContentsOfFile:filepath encoding:NSASCIIStringEncoding error:&err];
                                                      
                                                      NSArray *linesArray = [dataRaw componentsSeparatedByCharactersInSet:[NSCharacterSet characterSetWithCharactersInString:@",\r"]];
                                                      NSMutableArray* appts = [[NSMutableArray alloc]init];
                                                      
                                                      for(int i = 0; i < linesArray.count; i+=4)
                                                      {
                                                          NSMutableDictionary* appt = [[NSMutableDictionary alloc]init];
                                                          
                                                          appt[@"location"] = linesArray[i + 1];
                                                          appt[@"title"] = linesArray[i + 2];
                                                          
                                                          NSString* dateString = linesArray[i];
                                                          
                                                          float duration = ((NSString*)linesArray[i + 3]).floatValue;
                                                          
                                                          NSDateFormatter *df = [[NSDateFormatter alloc] init];
                                                          [df setDateFormat:@"MM.dd.yy HH:mm"];
                                                          NSDate* date;
                                                          [df getObjectValue:&date forString:dateString range:nil error:nil];
                                                          
                                                          NSDateComponents* comps = [[NSDateComponents alloc]init];
                                                          comps.minute = duration;
                                                          
                                                          NSCalendar* cal = [NSCalendar currentCalendar];
                                                          NSDate* endDate = [cal dateByAddingComponents:comps toDate:date options:0];
                                                          
                                                          appt[@"start"] = date;
                                                          appt[@"end"]= endDate;
                                                          
                                                          [appts addObject:appt];
                                                      }
                                                      
                                                      
                                                      [[NSOperationQueue mainQueue] addOperation: [NSBlockOperation blockOperationWithBlock:^(void)
                                                                                                   {
                                                                                                       _appts = [NSArray arrayWithArray:appts];
                                                                                                   }]];
                                                  }]];
}

@end
